@@ -4,15 +4,15 @@
 # 1fdx_my.B99990002.pdb.
 
 from modeller import *
-from modeller.automodel import *    # Load the automodel class
+from modeller.automodel import *    # Load the AutoModel class
 
 log.verbose()
-env = environ(rand_seed=-12312)  # To get different models from another script
+env = Environ(rand_seed=-12312)  # To get different models from another script
 
 # directories for input atom files
 env.io.atom_files_directory = ['../atom_files']
 
-a = automodel(env,
+a = AutoModel(env,
               alnfile='alignment.ali',      # alignment filename
               knowns=('1durA', '2fdnA'),    # codes of the templates
               sequence='1fdx_my',           # code of the target
